@@ -10,8 +10,8 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::EventListener;
-BEGIN {
-  $Curses::Toolkit::EventListener::VERSION = '0.207';
+{
+  $Curses::Toolkit::EventListener::VERSION = '0.208';
 }
 
 # ABSTRACT: base class for event listeners
@@ -40,7 +40,7 @@ sub can_handle {
     #	exists $self->{accepted_events}{$event_class} or return;
     if ( !exists $self->{accepted_events}{$event_class} ) {
         eval "require $event_class";
-        $@ and die "failed requireing event class '$event_class'";
+        $@ and die "failed requiring event class '$event_class'";
         my $found;
         foreach my $class_name ( keys %{ $self->{accepted_events} } ) {
             $event_class->isa($class_name)
@@ -133,7 +133,7 @@ Curses::Toolkit::EventListener - base class for event listeners
 
 =head1 VERSION
 
-version 0.207
+version 0.208
 
 =head1 DESCRIPTION
 
