@@ -10,8 +10,8 @@ use warnings;
 use strict;
 
 package Curses::Toolkit::Widget::ScrollArea;
-BEGIN {
-  $Curses::Toolkit::Widget::ScrollArea::VERSION = '0.207';
+{
+  $Curses::Toolkit::Widget::ScrollArea::VERSION = '0.208';
 }
 
 # ABSTRACT: a scrollable area
@@ -23,6 +23,11 @@ use Params::Validate qw(SCALAR ARRAYREF HASHREF CODEREF GLOB GLOBREF SCALARREF H
 use Curses::Toolkit::Widget::VScrollBar;
 use Curses::Toolkit::Widget::HScrollBar;
 
+our @EXPORT_OK = qw(ScrollArea);
+our %EXPORT_TAGS = (all => [qw(ScrollArea)]);
+
+sub ScrollArea { 'Curses::Toolkit::Widget::ScrollArea' }
+
 sub new {
     my $class = shift;
     my $self  = $class->SUPER::new();
@@ -34,6 +39,8 @@ sub new {
 #    $self->{visibility_mode} = 'auto';
     $self->{scroll_x} = 0;
     $self->{scroll_y} = 0;
+    $self->{_display_h_scrollbar} = 0;
+    $self->{_display_v_scrollbar} = 0;
     $self->{_main_child} = undef;
     $self->set_scrollbars_mode($params{scrollbars_mode});
     return $self;
@@ -43,20 +50,29 @@ sub set_scrollbars_mode {
     my ($self, $mode) = @_;
     if ($mode eq 'always') {
         $self->{scrollbars_mode} = $mode;
+
         $self->{v_scrollbar} = Curses::Toolkit::Widget::VScrollBar->new()->set_scroll_area($self)
           ->set_name($self . '_vscrollbar');
 
         # A bit hackish (especially the setting of iterator to undef. I should
         # stop using iterators anyway
-#        $self->_add_child_at_end($self->{v_scrollbar});
         $self->_add_child_at_beginning($self->{v_scrollbar});
         $self->{v_scrollbar}->_set_parent($self);
         $self->{v_scrollbar}->_set_iterator(undef);
 
+
+        $self->{h_scrollbar} = Curses::Toolkit::Widget::HScrollBar->new()->set_scroll_area($self)
+          ->set_name($self . '_hscrollbar');
+
+        # A bit hackish (especially the setting of iterator to undef. I should
+        # stop using iterators anyway
+        $self->_add_child_at_beginning($self->{h_scrollbar});
+        $self->{h_scrollbar}->_set_parent($self);
+        $self->{h_scrollbar}->_set_iterator(undef);
+
         # because it's a container, needs to take care of rebuilding coordinates
         # from top to bottom
         $self->rebuild_all_coordinates();
-        # $self->{h_scrollbar} = Curses::Toolkit::Widget::HScrollBar->new()->set_scroll_area($self);
     } else {
         die "scrollbar mode '" . $mode . "' is not supported";
     }
@@ -82,14 +98,44 @@ sub add_widget {
 
 sub scroll {
     my ($self, %params) = @_;
-    $self->{scroll_y} += 5;
-    $self->rebuild_all_coordinates();
-    $self->needs_redraw;
-return;
+#    $self->{scroll_y} += 5;
     defined $params{x}
       and $self->{scroll_x} += $params{x};
     defined $params{y}
       and $self->{scroll_y} += $params{y};
+
+    my $count = 0;
+    defined $self->{v_scrollbar}
+      and $count++;
+    defined $self->{h_scrollbar}
+      and $count++;
+    
+    my @children  = $self->get_children();
+    if (@children > $count) {
+
+        # there is a main child
+
+        my $shape = $self->get_visible_shape_for_children;
+        
+        # main child is always the last, so that widget ordering (for events for
+        # instance), find the scrollbar before the real child
+        my $child_widget = $children[-1];
+        if (defined $child_widget) {
+            # How much does the child widget want ? We don't specify a given size
+            my $child_space = $child_widget->get_desired_space();
+            $child_space->width + $self->{scroll_x} < $shape->width()
+              and $self->{scroll_x} = $shape->width() - $child_space->width;
+            $child_space->height + $self->{scroll_y} < $shape->height()
+              and $self->{scroll_y} = $shape->height() - $child_space->height;
+        }
+    }
+    $self->{scroll_x} >=0
+      and $self->{scroll_x} = 0;
+    $self->{scroll_y} >=0
+      and $self->{scroll_y} = 0;
+
+    $self->rebuild_all_coordinates();
+    $self->needs_redraw;
     return $self;
 }
 # Returns the relative rectangle that a child widget can occupy. Overloads the
@@ -161,9 +207,25 @@ sub _rebuild_children_coordinates {
     my $child_widget = $children[-1];
     defined $child_widget or return;
 
+    my $shape = $self->get_visible_shape_for_children;
+
     # How much does the child widget want ? We don't specify a given size
     my $child_space = $child_widget->get_desired_space();
 
+    $self->{_display_h_scrollbar} = 1;
+    $child_space->width <= $shape->width()
+      and $self->{scroll_x} = 0, $self->{_display_h_scrollbar} = 0;
+
+    $self->{_display_v_scrollbar} = 1;
+    $child_space->height <= $shape->height()
+      and $self->{scroll_y} = 0, $self->{_display_v_scrollbar} = 0;
+
+    $self->{h_scrollbar}
+      and $self->{h_scrollbar}->set_visible($self->{_display_h_scrollbar});
+
+    $self->{v_scrollbar}
+      and $self->{v_scrollbar}->set_visible($self->{_display_v_scrollbar});
+
     # scroll the space accordingly
     $child_space->set(
         x1 => $child_space->get_x1() + $self->{scroll_x}, y1 => $child_space->get_y1() + $self->{scroll_y},
@@ -176,7 +238,7 @@ sub _rebuild_children_coordinates {
         and $child_widget->_rebuild_children_coordinates();
 
     # take care of potential scrollbars
-    if ( defined ($self->{v_scrollbar}) ) {
+    if ( defined ($self->{v_scrollbar}) && $self->{_display_v_scrollbar} ) {
 
         my $c = $self->get_visible_shape;
         my ($child_widget)  = $self->get_children();
@@ -196,6 +258,22 @@ sub _rebuild_children_coordinates {
         $self->{v_scrollbar}->{theme_name} = $self->get_theme_name;
         $self->{v_scrollbar}->{theme} = $self->get_theme;
 #        $self->{v_scrollbar}->draw();
+    }
+    # take care of potential scrollbars
+    if ( defined ($self->{h_scrollbar}) && $self->{_display_h_scrollbar}) {
+
+        my $c = $self->get_visible_shape;
+
+        # XXX FIXME This is a Hack
+        $self->{h_scrollbar}->{coordinates} = Curses::Toolkit::Object::Coordinates->new(
+            x1 => $c->get_x1, y1 => $c->get_y2()-1,
+            x2 => $c->get_x2() - ( defined($self->{v_scrollbar}) ? 1 : 0), y2 => $c->get_y2(),
+        );
+
+        # XXX FIXME This is a Hack
+        $self->{h_scrollbar}->{theme_name} = $self->get_theme_name;
+        $self->{h_scrollbar}->{theme} = $self->get_theme;
+#        $self->{h_scrollbar}->draw();
     }
     return $self;
 }
@@ -205,10 +283,10 @@ sub get_visible_shape_for_children {
     my ($self) = @_;
     my $shape = $self->get_visible_shape();
     if ($shape->width > 0) {
-        $shape->set( x2 => $shape->get_x2() - 1);
+        $shape->set( x2 => $shape->get_x2() - $self->{_display_v_scrollbar});
     }
     if ($shape->height > 0) {
-        $shape->set( y2 => $shape->get_y2() - 1);
+        $shape->set( y2 => $shape->get_y2() - $self->{_display_h_scrollbar});
     }
     return $shape;
 }
@@ -266,7 +344,7 @@ Curses::Toolkit::Widget::ScrollArea - a scrollable area
 
 =head1 VERSION
 
-version 0.207
+version 0.208
 
 =head2 get_desired_space
 
